@@ -27,18 +27,24 @@ import javax.accessibility.*;
 
 public class AtkWrapper {
 	static {
-		// Set laf to Cross platform laf because GTK laf will be the default one in some
-		// environment, but GTK laf will not work well with gtk_main() started.
 		try {
-			String lafClassName = javax.swing.UIManager.getCrossPlatformLookAndFeelClassName();
-			if (lafClassName.contains("GTKLookAndFeel")) {
-				javax.swing.UIManager.setLookAndFeel(
-					javax.swing.UIManager.getCrossPlatformLookAndFeelClassName());
+			Process p = Runtime.getRuntime().exec("/usr/X11/bin/xprop -root");
+			BufferedReader b = new BufferedReader (
+					new InputStreamReader (p.getInputStream ()));
+			String result;
+			boolean found = false;
+			while ((result = b.readLine()) != null) {
+				if (result.indexOf ("AT_SPI_IOR") >= 0) {
+					found = true;
+					break;
+				}
+			}
+			
+			if (found) {
+				System.loadLibrary("atk-wrapper");
+				AtkWrapper.initNativeLibrary();
 			}
 		} catch (Exception e) { }
-
-		System.loadLibrary("atk-wrapper");
-		AtkWrapper.initNativeLibrary();
 	}
 
 	final WindowAdapter winAdapter = new WindowAdapter() {
